==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'icone_evolution_visites' => 'Evolucion dei vesitas<br />@visites@ vesitas',
	'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
	'icone_repartition_visites' => 'Reparticion dei vesitas',
	'icone_statistiques_visites' => 'Estadisticas',
	'info_affichier_visites_articles_plus_visites' => 'Afichar li vesitas per lu <b>articles mai vesitats despí lo començament:</b>',
	'info_comment_lire_tableau' => 'Coma legir aqueu tablèu',
	'info_forum_statistiques' => 'Estadisticas dei vesitas',
	'info_popularite_2' => 'popularitat dau sit:',
	'info_popularite_3' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_popularite_5' => 'popularitat:',
	'info_visites' => 'vesitas:',
	'info_visites_plus_populaires' => 'Afichar li vesitas <b>per lu articles mai populars</b> e <b>per lu darriers articles publicats:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gerir li estadisticas', # MODIF

	// O
	'onglet_origine_visites' => 'Orígina dei vesitas',
	'onglet_repartition_debut' => 'despí la començança',
	'onglet_repartition_lang' => 'Reparticion per lengas',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Lo reng de l’article,
dins lo classament per popularitat, es indicat dins lo marge; la popularitat de l’article 
(una estimacion dau nombre de vesitas quotidiani qu’eu recebrà se lo ritme actuau de consultacion si manten) e lo nombre de vesitas recebudi
despí lo començament s’afichan dins la bofiga 
qu’apareisse quora la rateta passa sus lo títol.',
	'texte_signification' => 'Li barras escuri representan li intradas cumuladi (totau dei sosrubricas), li barras clari lo nombre de vesitas per cada rubrica.',
	'titre_evolution_visite' => 'Evolucion dei vesitas',
	'titre_liens_entrants' => 'Lu ligams intrants',
	'titre_page_statistiques' => 'Estadisticas per rubricas',
	'titre_page_statistiques_visites' => 'Estadisticas dei vesitas'
);

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

return [

	// I
	'icone_evolution_visites' => 'Evolucion dei vesitas<br />@visites@ vesitas',
	'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
	'icone_repartition_visites' => 'Reparticion dei vesitas',
	'icone_statistiques_visites' => 'Estadisticas',
	'info_affichier_visites_articles_plus_visites' => 'Afichar li vesitas per lu <b>articles mai vesitats despí lo començament:</b>',
	'info_comment_lire_tableau' => 'Coma legir aqueu tablèu',
	'info_forum_statistiques' => 'Estadisticas dei vesitas',
	'info_popularite_2' => 'popularitat dau sit:',
	'info_popularite_3' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_popularite_5' => 'popularitat:',
	'info_visites' => 'vesitas:',
	'info_visites_plus_populaires' => 'Afichar li vesitas <b>per lu articles mai populars</b> e <b>per lu darriers articles publicats:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gerir li estadisticas', # MODIF

	// O
	'onglet_origine_visites' => 'Orígina dei vesitas',
	'onglet_repartition_debut' => 'despí la començança',
	'onglet_repartition_lang' => 'Reparticion per lengas',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Lo reng de l’article,
dins lo classament per popularitat, es indicat dins lo marge; la popularitat de l’article 
(una estimacion dau nombre de vesitas quotidiani qu’eu recebrà se lo ritme actuau de consultacion si manten) e lo nombre de vesitas recebudi
despí lo començament s’afichan dins la bofiga 
qu’apareisse quora la rateta passa sus lo títol.',
	'texte_signification' => 'Li barras escuri representan li intradas cumuladi (totau dei sosrubricas), li barras clari lo nombre de vesitas per cada rubrica.',
	'titre_evolution_visite' => 'Evolucion dei vesitas',
	'titre_liens_entrants' => 'Lu ligams intrants',
	'titre_page_statistiques' => 'Estadisticas per rubricas',
	'titre_page_statistiques_visites' => 'Estadisticas dei vesitas',
];
